/**
*
* A method to initialize a list of radios buttons to present the user with a group of single choice options. It takes as the main argument, a unique selector identifying the view or section where the radio list resides.
*
* @method
*
* ### RadioButtons
*
* syntax:
*
*  $.RadioButtons(selector);
*
* arguments:
*
*  - string: string A valid selector for the parent of the tab control. By default the selector will target a class, id or tag of the radio list itself, so if you want to pass in a selector for a parent tag, such as an article, section or div tag, you'll need to make sure to put a trailing space on the end of the selector string.
*  - function: function A valid function as a callback. This is optional. The callback gets passed a reference to the clicked item, so you can access it in your callback function.
*
* example:
*
*  $.RadioButtons("#buyerOptions");
*  $.RadioButtons("#buyerOptions", function(choice) {
       // Output the value of the radio button that was selected.
       // Since the actual radio button is the last item in a radio
       // button list, we can use the last() method to get its value.
       console.log(choice.last().value);
   };
**/

$.RadioButtons = function( viewSelector, callback ) {
    var items = viewSelector + ".radioList li";
    var radioButtons = $$(items);
    radioButtons.forEach(function(item) {
    	if (item.lastElementChild.checked == true) {
    		item.addClass("selected");
    	}
        item.bind("click", function() {
            radioButtons.forEach(function(check) {
                check.removeClass("selected");
            });
            this.addClass("selected");
            answered(item.lastElementChild.getAttribute("value"));
            this.last().checked = true;
            if (callback) {
                callback(item);
            }
        });
    });
};

$.RadioButtonRefresh = function( viewSelector, callback ) {
    var items = viewSelector + ".radioList li";
    var radioButtons = $$(items);
    radioButtons.forEach(function(item) {
    	if (item.lastElementChild.checked == true) {
    		item.addClass("selected");
    	}
    });
};
